*-------------------------------------------------------------------------------

/*
TITLE: Figures for Cool to be Smart or Smart to be Cool

DESCRIPTION: Generates Figure 2-10, A.1, and A.2. 

INPUT: 
bursztyn_egorov_jensen_restud.dta:


OUTPUT: 
figure2
figure3
...
figure10
figureA1
figureA2

Created Figures:

2. Effect of Public Treatment on Signup Decision
3. Effect of Public Treatment and Probability of Winning the SAT Prep Package
on Signup Decision { Lower Income School
4. Effect of Public Treatment and Probability of Winning the SAT Prep Package
on Signup Decision { Higher Income Schools
5. Signup Rates for Public Decisions: Split by Grades - Higher Income Schools
6. Signup Rates for Private Decisions: Split by Grades - Higher Income Schools
7. Signup Rates for Private vs. Public Decisions: Importance of Being Popular
- Lower Income School
8. Signup Rates for Private vs. Public Decisions: Importance of Being Popular
- Higher Income Schools
9. Effect of Public Treatment and Probability of Winning the SAT Prep Package
on Signup Decision - Classrooms Below Median in Opinion on Importance of Being
Considered Smart to be Popular
10. Effect of Public Treatment and Probability of Winning the SAT Prep Package
on Signup Decision - Classrooms Above Median in Opinion on Importance of Being
Considered Smart to be Popula

A.1. Signup Rates for Public Decisions: Split by Grades – Lower Income School
A.2. Signup Rates for Private Decisions: Split by Grades – Lower Income School
*/

*-------------------------------------------------------------------------------


set more off
clear
use "bursztyn_egorov_jensen_restud.dta", clear
mkdir figures

** Data manipulation
** ~~~~~~~~~~~~~~~~~~

* Interactions for school type
gen private=(1-public)
gen privateXff=private*ffschools
gen publicXff=public*ffschools
gen privateXaw=private*(1-ffschools)
gen publicXaw=public*(1-ffschools)

* Interactions for popularity

gen popXprivate=imp_pop*(1-public)
gen popXpublic=imp_pop*public
gen notpopXprivate=(1-imp_pop)*(1-public)
gen notpopXpublic=(1-imp_pop)*public

* Interactions for smart 

gen smartXprivate=important_smart*(1-public)
gen smartXpublic=important_smart*public
gen notsmartXprivate=(1-important_smart)*(1-public)
gen notsmartXpublic=(1-important_smart)*public

* Interactinos for grades
gen high_grades=(grades<=2)
replace high_grades=. if grades==.
gen grades_low=1-high_grades

gen lowgradeXlow=grades_low*lowp
gen highgradeXlow=high_grades*lowp
gen lowgradeXhigh=grades_low*(1-lowp)
gen highgradeXhigh=high_grades*(1-lowp)


** Figures 
** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Fig 2: Public vs private for both types of school

preserve
	mat R=J(4,4,.)
	reg takeup privateXaw publicXaw privateXff publicXff   , robust noc
	
	local row=1
	
	foreach X in  privateXaw publicXaw privateXff publicXff  {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	la var R1 "Sign-up rate"
	label define groups 1 "Private" 2 "Public" 3 "Private" 4 "Public"
	label values R4 groups
	
	
	set scheme s2mono
		
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "79%") text(0.20 2 "53%") text(0.20 3 "80%") text(0.20 4 "53%") ///
		text(0.95 1.5 "p-value=0.000") text(0.95 3.5 "p-value=0.000") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Smart-to-be-Cool School") text(1.08 3.5 "Cool-to-be-Smart Schools")  ///
	
	
	
	graph save Graph "figure2.gph", replace
	graph export "figures/figure2.png ", replace
	
restore

* Figs 3 and 4 - Social school main, economic school main

* Figure 3
preserve
	mat R=J(4,4,.)
	reg takeup privateXlow privateXhigh publicXlow publicXhigh  if school=="StbC"  , robust noc
	
	local row=1
	
	foreach X in privateXlow privateXhigh publicXlow publicXhigh {
	
		mat R[`row',1]=_b[`X']
		mat R[`row',2]=_b[`X']-1.96*_se[`X']
		mat R[`row',3]=_b[`X']+1.96*_se[`X']
		mat R[`row',4]=`row'
		
		local ++row
	
	}
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Sign-up rate"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "80%") text(0.20 2 "78%") text(0.20 3 "44%") text(0.20 4 "62%") ///
		text(0.95 1.5 "p-value=0.796") text(0.95 3.5 "p-value=0.049") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Private decision") text(1.08 3.5 "Public decision")  ///
		title("Smart-to-be-Cool School")
	
	
	graph save Graph "figure3.gph", replace
	graph export "figures/figure3.png ", replace
	
restore

* Figure 4
preserve
	
	mat R=J(4,4,.)
	reg takeup privateXlow privateXhigh publicXlow publicXhigh  if school!="StbC"  , robust noc
	
	local row=1
	
	foreach X in privateXlow privateXhigh publicXlow publicXhigh {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Sign-up rate"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "81%") text(0.20 2 "80%") text(0.20 3 "66%") text(0.20 4 "40%") ///
		text(0.95 1.5 "p-value=0.894") text(0.95 3.5 "p-value=0.002") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Private decision") text(1.08 3.5 "Public decision")  ///
		title("Cool-to-be-Smart Schools")
	
	graph save Graph "figure4.gph", replace
	graph export "figures/figure4.png ", replace
	
restore


* Figure 4

preserve
	mat R=J(4,4,.)
	reg takeup lowgradeXlow lowgradeXhigh highgradeXlow highgradeXhigh  if private==0 & school!="StbC" , robust noc
	
	local row=1
	
	foreach X in   lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Share of students with grades below median"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "67%") text(0.15 2 "22%") text(0.20 3 "66%") text(0.20 4 "51%") ///
		text(0.95 1.5 "p-value=0.000") text(0.95 3.5 "p-value=0.243") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Grades below median") text(1.08 3.5 "Grades above median")  ///
		title("Cool-to-be-Smart Schools: Public Decisions")
		
	graph save Graph "figure5.gph", replace
	graph export "figures/figure5.png ", replace

restore

preserve
	mat R=J(4,4,.)
	reg takeup lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh  if public==0 & school!="StbC" , robust noc
	
	local row=1
	
	foreach X in   lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Share of students with grades below median"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "82%") text(0.20 2 "80%") text(0.20 3 "79%") text(0.20 4 "79%") ///
		text(0.95 1.5 "p-value=0.872") text(0.95 3.5 "p-value=0.982") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Grades below median") text(1.08 3.5 "Grades above median")  ///	   
		title("Cool-to-be-Smart Schools: Private Decisions")
		
	graph save Graph "figure6.gph", replace
	graph export "figures/figure6.png ", replace

restore

* Figure 5
preserve
	mat R=J(4,4,.)
	reg takeup lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh  if private==0 & school=="StbC" , robust noc
	
	local row=1
	
	foreach X in   lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh {
   
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Share of students with grades below median"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "43%") text(0.20 2 "64%") text(0.20 3 "50%") text(0.20 4 "58%") ///
		text(0.95 1.5 "p-value=0.055") text(0.95 3.5 "p-value=0.626") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Grades below median") text(1.08 3.5 "Grades above median")  ///
		title("Smart-to-be-Cool School: Public Decisions")
		
	graph save "figure7.gph", replace
	graph export "figures/figure7.png ", replace

restore

preserve
	mat R=J(4,4,.)
	reg takeup lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh  if public==0 & school=="StbC" , robust noc
	
	local row=1
	
	foreach X in   lowgradeXlow  lowgradeXhigh highgradeXlow highgradeXhigh {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Share of students with grades below median"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "75%") text(0.20 2 "72%") text(0.20 3 "94%") text(0.20 4 "100%") ///
		text(0.95 1.5 "p-value=0.741") text(0.98 3.35 "p-value=0.313") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Grades below median") text(1.08 3.5 "Grades above median")  ///	   
		title("Smart-to-be-Cool School: Private Decisions")
		
	graph save "figure8.gph", replace
	graph export "figures/figure8.png ", replace

restore


* Figure 6

preserve
	mat R=J(4,4,.)
	reg takeup popXprivate popXpublic notpopXprivate notpopXpublic if school=="StbC"  , robust noc
	
	local row=1
	
	foreach X in popXprivate popXpublic notpopXprivate notpopXpublic {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Sign-up rate"
	
	
	label define groups 1 "Private   " 2 "Public" 3 "Private" 4 "Public"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "81%") text(0.20 2 "47%") text(0.20 3 "78%") text(0.20 4 "59%") ///
		text(0.95 1.5 "p-value=0.000") text(0.95 3.5 "p-value=0.016") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Important to be popular") text(1.08 3.5 "Not important to be popular")  ///
		title("Smart-to-be-Cool School")
	
	graph save "figure9.gph", replace
	graph export "figures/figure9.png ", replace

restore

preserve
	mat R=J(4,4,.)
	reg takeup popXprivate popXpublic notpopXprivate notpopXpublic if school!="StbC"  , robust noc
	
	local row=1
	
	foreach X in popXprivate popXpublic notpopXprivate notpopXpublic {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Sign-up rate"
	
	
	label define groups 1 "Private   " 2 "Public" 3 "Private" 4 "Public"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.97 1.5 "p-value=0.000") text(0.97 3.5 "p-value=0.087") ///
		text(0.20 1 "93%") text(0.20 2 "50%") text(0.20 3 "70%") text(0.20 4 "56%") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Important to be popular") text(1.08 3.5 "Not important to be popular")  ///
		title("Cool-to-be-Smart Schools")
	
	
	graph save "figure10.gph", replace
	graph export "figures/figure10.png ", replace
	
restore


* Figure 7
preserve
	mat R=J(4,4,.)
	reg takeup  privateXlow privateXhigh publicXlow publicXhigh  if high_smart==0  , robust noc
	
	local row=1
	
	foreach X in privateXlow privateXhigh publicXlow publicXhigh {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Sign-up rate"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "81%") text(0.20 2 "81%") text(0.20 3 "45%") text(0.20 4 "61%") ///
		text(0.95 1.5 "p-value=0.968") text(0.95 3.5 "p-value=0.059") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Private decision") text(1.08 3.5 "Public decision")  ///
		title("Below Median Classrooms")
	
	
	graph save "figure11.gph", replace
	graph export "figures/figure11.png ", replace

restore


* Figure 10
preserve
	mat R=J(4,4,.)
	reg takeup privateXlow privateXhigh publicXlow publicXhigh  if high_smart==1  , robust noc
	
	local row=1
	
	foreach X in privateXlow privateXhigh publicXlow publicXhigh  {
	
	
	mat R[`row',1]=_b[`X']
	mat R[`row',2]=_b[`X']-1.96*_se[`X']
	mat R[`row',3]=_b[`X']+1.96*_se[`X']
	mat R[`row',4]=`row'
	
	local ++row
	}
	
	
	clear
	svmat R
	
	la var R4 Group
	
	la var R1 "Sign-up rate"
	
	
	label define groups 1 "Low probability" 2 "High probability" 3 "Low probability" 4 "High probability"
	
	
	
	label values R4 groups
	
	
	set scheme s2mono
	
	twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
		(rcap R3 R2 R4, lc(gs5)), ///
		legend(off) xlabel(1/4, valuelabel) ///
		ylabel(0(0.1)1) yscale(range(1.1))  ///
		xline(2.5, lpattern(-) lcolor(black)) ///
		text(0.20 1 "79%") text(0.20 2 "77%") text(0.20 3 "67%") text(0.20 4 "41%") ///
		text(0.95 1.5 "p-value=0.731") text(0.95 3.5 "p-value=0.003") ///
		graphregion(color(white))    ytitle("Sign-up rate") ///
		text(1.08 1.5 "Private decision") text(1.08 3.5 "Public decision")  ///
		title("Above Median Classrooms")
	
	
	graph save "figure12.gph", replace
	graph export "figures/figure12.png ", replace
	
restore


