*-------------------------------------------------------------------------------

/*
TITLE: Permutation Test for Cool to be Smart or Smart to be Cool

DESCRIPTION: Generates permutation test p-values

INPUT: 
from bursztyn_egorov_jensen_restud.dta: 
	grades 
	takeup 
	ffschools
	lowprob
	publicXhigh  
	publicXlow  
	privateXhigh  
	privateXlow    
	imp_popular  
	important_smart  
	high_smart 

Note: p-values generated from permutation tests will not exactly match those in paper,
but the differences are small and insignificant. 
*/

*-------------------------------------------------------------------------------

set seed 1

set matsize 1000

capture log close

capture log using "Permutations.log", replace


set more off
clear
use "bursztyn_egorov_jensen_restud", clear


******************************** Table 2: EFFECT OF PUBLIC TREATMENT ON SIGNUP DECISION

******************  COLUMN 1 ******************
keep if school== "StbC"
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()
xtile temp=r , n(257)
gen T = (temp<=126)
xi: reg takeup T if school== "StbC", r
mat R[`row',1]=_b[T]
drop T temp r
display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.2621471 |R1<-.2621471)
sum test*

******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school== "StbC"

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(257)

gen T = (temp<=126)

xi: reg takeup T male age hispanic if school== "StbC", r

mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>0.2595236  |R1<-0.2595236 )
sum test*

******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school== "StbC"
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(257)


gen T = (temp<=126)

xi: reg takeup T  male age hispanic i.classroom i.surv if school=="StbC", r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.
gen test1=(R1>0.2561383 |R1<-.2561383)
sum test*


******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(254)


gen T = (temp<=128)

xi: reg takeup T if school!= "StbC", r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.2703373  |R1<-.2703373 )
sum test*

******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(254)


gen T = (temp<=128)


xi: reg takeup T male age hispanic if school!= "StbC", r

mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.251691  |R1<-.251691 )
sum test*

******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(254)


gen T = (temp<=128)

xi: reg takeup T  male age hispanic i.classroom i.surv if school!="StbC", r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.
gen test1=(R1>.2484465|R1<-.2484465)
sum test*


******************************** TABLE 3: EFFECT OF PUBLIC TREATMENT AND LOW PROBABILITY ON SIGNUP DECISION


******************  COLUMN 1 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school== "StbC"
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(257)


* T1 is public low
gen T1 = (temp<=63)

* T2 is private high
gen T2 = (temp>63 & temp<=128)

* T3 is private_low
gen T3 = (temp>128 & temp<=194)


xi: reg takeup T1 T2 T3 if school=="StbC" , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]
mat R[`row',3]=_b[T1]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.


gen test1=(R1>.1655678 |R1<-.1655678)
gen test2=(R2>.1930181 |R2<-.1930181)
gen test3=(R3>.1746032 |R3<-.1746032)
sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

keep if school== "StbC"
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(257)


* T1 is public low
gen T1 = (temp<=63)

* T2 is private high
gen T2 = (temp>63 & temp<=128)

* T3 is private_low
gen T3 = (temp>128 & temp<=194)




xi: reg takeup T1 T2 T3 male age hispanic if school=="StbC" , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]
mat R[`row',3]=_b[T1]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.


gen test1=(R1>.1655678 |R1<-.1655678)
gen test2=(R2>.1930181 |R2<-.1930181)
gen test3=(R3>.1738999  |R3<-.1738999)
sum test*




******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school== "StbC"
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(257)


* T1 is public low
gen T1 = (temp<=63)

* T2 is private high
gen T2 = (temp>63 & temp<=128)

* T3 is private_low
gen T3 = (temp>128 & temp<=194)




xi: reg takeup T1 T2 T3 male age hispanic i.surveyor i.classroom if school=="StbC" , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]
mat R[`row',3]=_b[T1]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.


gen test1=(R1>.1655678 |R1<-.1655678)
gen test2=(R2>.1930181 |R2<-.1930181)
gen test3=(R3>.1738501  |R3<-.1738501)
sum test*



******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(254)


* T1 is public low
gen T1 = (temp<=65)

* T2 is private high
gen T2 = (temp>65 & temp<=129)

* T3 is private_low
gen T3 = (temp>130 & temp<=192)



xi: reg takeup T1 T2 T3 if school!="StbC" , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]
mat R[`row',3]=_b[T1]

drop T1 T2 T3  temp r

display `row'

}
}
clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.


gen test1=(R1>.4000496 |R1<-.4000496)
gen test2=(R2>.2551365 |R2<-.2551365)
gen test3=(R3>.2647131 |R3<-.2647131 )
sum test*



sum test*



******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(254)


* T1 is public low
gen T1 = (temp<=65)

* T2 is private high
gen T2 = (temp>65 & temp<=129)

* T3 is private_low
gen T3 = (temp>130 & temp<=192)



xi: reg takeup T1 T2 T3 age male hispanic if school!="StbC" , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]
mat R[`row',3]=_b[T1]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.3751609 |R1<-.3751609)
gen test2=(R2>.2414004 |R2<-.2414004)
gen test3=(R3>.2489689 |R2<-.2489689)

sum test*


******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

keep if school!= "StbC"
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(254)


* T1 is public low
gen T1 = (temp<=65)

* T2 is private high
gen T2 = (temp>65 & temp<=129)

* T3 is private_low
gen T3 = (temp>130 & temp<=192)



xi: reg takeup T1 T2 T3 age male hispanic i.surveyor i.classroom if school!="StbC" , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]
mat R[`row',3]=_b[T1]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.


gen test1=(R1>.3793753 |R1<-.3793753)
gen test2=(R2>.2571387 |R2<-.2571387)
gen test3=(R3>.2648832 |R3<-.2648832)

sum test*

******************************** Table 4:  EFFECT OF HIGH PROBALITY ON SIGNUP: SPLIT BY GRADES (COOL-TO-BE-SMART SCHOOLS)

******************  COLUMN 1 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!="StbC" & public==1
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(127)

* T1 is highprob highgrade
gen T1 = (temp<=35)

* T2 is highprob lowgrade
gen T2 = (temp>36 & temp<=63)

* T3 is lowprob lowgrade
gen T3 = (temp>63 & temp<=96)


xi: reg takeup T1 T2 T3 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.2920635  |R1<-.2920635 )
gen test2=(R2>.4444445 |R2<-.4444445)
gen test3=(R3>.3024802   |R3<-.3024802)

sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear


keep if school!="StbC" & public==1
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(127)



* T1 is highprob highgrade
gen T1 = (temp<=35)

* T2 is highprob lowgrade
gen T2 = (temp>36 & temp<=63)

* T3 is lowprob lowgrade
gen T3 = (temp>63 & temp<=96)


xi: reg takeup T1 T2 T3 male age hispanic, r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.3263185  |R1<-.3263185)
gen test2=(R2>.4960503 |R2<-.4960503)
gen test3=(R3>.3622628   |R3<-.3622628)

sum test*


******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!="StbC" & public==1
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(127)



* T1 is highprob highgrade
gen T1 = (temp<=35)

* T2 is highprob lowgrade
gen T2 = (temp>36 & temp<=63)

* T3 is lowprob lowgrade
gen T3 = (temp>63 & temp<=96)


xi: reg takeup T1 T2 T3 male age hispanic i.surv i.classr, r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.2979077    |R1<-.2979077)
gen test2=(R2>.5098517 |R2<-.5098517)
gen test3=(R3>.3369752  |R3<-.3369752)

sum test*




******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!="StbC" & public==0
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(126)



* T1 is highprob highgrade
gen T1 = (temp<=34)

* T2 is highprob lowgrade
gen T2 = (temp>35 & temp<=65)

* T3 is lowprob lowgrade
gen T3 = (temp>65 & temp<=103)


xi: reg takeup T1 T2 T3 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.0058824    |R1<-.0058824)
gen test2=(R2>.0157894 |R2<-.0157894)
gen test3=(R3>.0182404  |R3<-.0182404)

sum test*




******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!="StbC" & public==0
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(126)



* T1 is highprob highgrade
gen T1 = (temp<=34)

* T2 is highprob lowgrade
gen T2 = (temp>35 & temp<=65)

* T3 is lowprob lowgrade
gen T3 = (temp>65 & temp<=103)


xi: reg takeup T1 T2 T3 male age , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.02367    |R1<-.02367)
gen test2=(R2>.0176136 |R2<-.0176136)
gen test3=(R3>.0013472  |R3<-.0013472)

sum test*


*/
******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!="StbC" & public==0

mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(126)


* T1 is highprob highgrade
gen T1 = (temp<=34)

* T2 is highprob lowgrade
gen T2 = (temp>35 & temp<=65)

* T3 is lowprob lowgrade
gen T3 = (temp>65 & temp<=103)


xi: reg takeup T1 T2 T3 male age hispanic i.surv i.classr, r

mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.0302889    |R1<-.0302889)
gen test2=(R2>.0051589 |R2<-.0051589)
gen test3=(R3>.03090172  |R3<-.0309017)

sum test*


******************************** Table 5:  EFFECT OF HIGH PROBALITY ON SIGNUP: SPLIT BY GRADES (SMART-TO-BE-COOL SCHOOLS)

******************  COLUMN 1 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school=="StbC" & public==1
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(127)

* T1 is highprob highgrade
gen T1 = (temp<=35)

* T2 is highprob lowgrade
gen T2 = (temp>36 & temp<=63)

* T3 is lowprob lowgrade
gen T3 = (temp>63 & temp<=96)


xi: reg takeup T1 T2 T3 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>0.0789  |R1<-0.0789 )
gen test2=(R2<-0.2077 |R2>0.2077)
gen test3=(R3<-.1288   |R3>.1288)

sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear


keep if school=="StbC" & public==1
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(127)



* T1 is highprob highgrade
gen T1 = (temp<=35)

* T2 is highprob lowgrade
gen T2 = (temp>36 & temp<=63)

* T3 is lowprob lowgrade
gen T3 = (temp>63 & temp<=96)


xi: reg takeup T1 T2 T3 male age hispanic, r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>0.034  |R1<-0.034)
gen test2=(R2>0.2227 |R2<-.2227)
gen test3=(R3>.1887   |R3<-.1887)

sum test*


******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school=="StbC" & public==1
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(127)



* T1 is highprob highgrade
gen T1 = (temp<=35)

* T2 is highprob lowgrade
gen T2 = (temp>36 & temp<=63)

* T3 is lowprob lowgrade
gen T3 = (temp>63 & temp<=96)


xi: reg takeup T1 T2 T3 male age hispanic i.surv i.classr, r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>0.1184    |R1<-.1184)
gen test2=(R2>.1865 |R2<-.1865)
gen test3=(R3>.0681  |R3<-.0681)

sum test*




******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school=="StbC" & public==0
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(126)



* T1 is highprob highgrade
gen T1 = (temp<=34)

* T2 is highprob lowgrade
gen T2 = (temp>35 & temp<=65)

* T3 is lowprob lowgrade
gen T3 = (temp>65 & temp<=103)


xi: reg takeup T1 T2 T3 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.0556    |R1<-.0556)
gen test2=(R2>.03 |R2<-.03)
gen test3=(R3>.0856  |R3<-.0856)

sum test*




******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school=="StbC" & public==0
mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(126)



* T1 is highprob highgrade
gen T1 = (temp<=34)

* T2 is highprob lowgrade
gen T2 = (temp>35 & temp<=65)

* T3 is lowprob lowgrade
gen T3 = (temp>65 & temp<=103)


xi: reg takeup T1 T2 T3 male age , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.0586    |R1<-.0586)
gen test2=(R2>.0244 |R2<-.0244)
gen test3=(R3>.083  |R3<-.083)

sum test*


*/
******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school=="StbC" & public==0

mat R=J(1000,3,.)

forvalues row=1(1)1000 {
quietly{

gen r=runiform()

xtile temp=r , n(126)


* T1 is highprob highgrade
gen T1 = (temp<=34)

* T2 is highprob lowgrade
gen T2 = (temp>35 & temp<=65)

* T3 is lowprob lowgrade
gen T3 = (temp>65 & temp<=103)


xi: reg takeup T1 T2 T3 male age hispanic i.surv i.classr, r

mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]-_b[T1]
mat R[`row',3]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.
drop if R3==.

gen test1=(R1>.0776    |R1<-.0776)
gen test2=(R2>.0267 |R2<-.0267)
gen test3=(R3>.1043  |R3<-.1043)

sum test*


******** TABLE 6: EFFECT OF PUBLIC TREATMENT ON SIGNUP DECISION: BY IMPORTANCE OF POPULARITY
set seed 1

set matsize 1000

capture log close

capture log using "Permutations.log", replace


set more off
clear
use "bursztyn_egorov_jensen_restud.dta", clear



******************  COLUMN 1 ******************
keep if school== "StbC"
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(255)


gen T = (temp<=124)

gen TXpop=T*imp_pop
gen TXnotpop=T*(1-imp_pop)

reg takeup  TXpop  TXnot imp_pop if school=="StbC"  , robust 


mat R[`row',1]=_b[TXpop]
mat R[`row',2]=_b[TXnot]

drop T TXpop TXnot  temp r

display `row'

}
}
clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3378257 |R1<-.3378257)
gen test2=(R2>.1878625 |R2<-.1878625)

sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school== "StbC"
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(255)


gen T = (temp<=124)

gen TXpop=T*imp_pop
gen TXnotpop=T*(1-imp_pop)

reg takeup  TXpop  TXnot imp_pop male age hispanic if school=="StbC"  , robust 


mat R[`row',1]=_b[TXpop]
mat R[`row',2]=_b[TXnot]

drop T TXpop TXnot  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3374392 |R1<-.3374392)
gen test2=(R2>.1856904 |R2<-.1856904)

sum test*

******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school== "StbC"
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(255)


gen T = (temp<=124)

gen TXpop=T*imp_pop
gen TXnotpop=T*(1-imp_pop)

reg takeup  TXpop  TXnot imp_pop male age hispanic i.classroom i.surv if school=="StbC"  , robust 


mat R[`row',1]=_b[TXpop]
mat R[`row',2]=_b[TXnot]

drop T TXpop TXnot  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3268096 |R1<-.3268096)
gen test2=(R2>.1932459  |R2<-.1932459)

sum test*


******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(254)


gen T = (temp<=128)

gen TXpop=T*imp_pop
gen TXnotpop=T*(1-imp_pop)

reg takeup  TXpop  TXnot imp_pop if school!="StbC"  , robust 


mat R[`row',1]=_b[TXpop]
mat R[`row',2]=_b[TXnot]

drop T TXpop TXnot  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.4285714 |R1<-.4285714)
gen test2=(R2>.1411765|R2<-.1411765)

sum test*



******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(254)


gen T = (temp<=128)

gen TXpop=T*imp_pop
gen TXnotpop=T*(1-imp_pop)

reg takeup  TXpop  TXnot imp_pop male age hispanic if school!="StbC"  , robust 


mat R[`row',1]=_b[TXpop]
mat R[`row',2]=_b[TXnot]

drop T TXpop TXnot  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3819702 |R1<-.3819702)
gen test2=(R2>.147943 |R2<-.147943)

sum test*

******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if school!= "StbC"
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(254)


gen T = (temp<=128)

gen TXpop=T*imp_pop
gen TXnotpop=T*(1-imp_pop)

reg takeup  TXpop  TXnot imp_pop male age hispanic i.classroom i.surv if school!="StbC"  , robust 


mat R[`row',1]=_b[TXpop]
mat R[`row',2]=_b[TXnot]

drop T TXpop TXnot  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3878307 |R1<-.3878307)
gen test2=(R2>.1355466 |R2<-.1355466)

sum test*



******** TABLE 7:  EFFECT OF PUBLIC TREATMENT AND LOW PROBABILITY ON SIGNUP DECISION: MEDIAN SPLIT OF CLASSROOMS BY
*AVERAGE OPINION ON IMPORTANCE OF BEING CONSIDERED SMART TO BE POPULAR

clear
set more off
clear matrix
set seed 1
set matsize 1000
capture log close
capture log using "Permutation_Table7.log", replace

use "bursztyn_egorov_jensen_restud.dta", clear



******************  COLUMN 1 ******************
keep if high_smart==0
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(266)



* T1 is private low
gen T1 = (temp<=70)

* T2 is public high
gen T2 = (temp>70 & temp<=135)

* T3 is public low
gen T3 = (temp>135 & temp<=197)


xi: reg takeup T1 T2 T3 if high_smart==0 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'

}
}
clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.198691 |R1<-.198691)
gen test2=(R2>.1694409    |R2<-.1694409)

sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

keep if high_smart==0
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(266)



* T1 is private low
gen T1 = (temp<=70)

* T2 is public high
gen T2 = (temp>70 & temp<=135)

* T3 is public low
gen T3 = (temp>135 & temp<=197)


xi: reg takeup T1 T2 T3 male age hispanic if high_smart==0 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r


display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.1988352 |R1<-.1988352)
gen test2=(R2>.1671558 |R2<-.1671558)

sum test*


******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

keep if high_smart==0
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(266)



* T1 is private low
gen T1 = (temp<=70)

* T2 is public high
gen T2 = (temp>70 & temp<=135)

* T3 is public low
gen T3 = (temp>135 & temp<=197)


xi: reg takeup T1 T2 T3 male age hispanic i.classroom i.surv if high_smart==0 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r

display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.2060475 |R1<-.2060475)
gen test2=(R2>.1530825 |R2<-.1530825)

sum test*


******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if high_smart==1
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(245)



* T1 is private low
gen T1 = (temp<=58)

* T2 is public high
gen T2 = (temp>58 & temp<=122)

* T3 is public low
gen T3 = (temp>122 & temp<=185)


xi: reg takeup T1 T2 T3 if high_smart==1 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r


display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3604167 |R1<-.3604167)
gen test2=(R2>.2339799 |R2<-.2339799)

sum test*



******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

keep if high_smart==1
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(245)



* T1 is private low
gen T1 = (temp<=58)

* T2 is public high
gen T2 = (temp>58 & temp<=122)

* T3 is public low
gen T3 = (temp>122 & temp<=185)


xi: reg takeup T1 T2 T3 male age hispanic if high_smart==1 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r


display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3466195 |R1<-.3466195)
gen test2=(R2>.2296494 |R2<-.2296494)

sum test*


******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

keep if high_smart==1
mat R=J(1000,2,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(245)


* T1 is private low
gen T1 = (temp<=58)

* T2 is public high
gen T2 = (temp>58 & temp<=122)

* T3 is public low
gen T3 = (temp>122 & temp<=185)


xi: reg takeup T1 T2 T3 male age hispanic i.classroom i.surv if high_smart==1 , r


mat R[`row',1]=_b[T2]
mat R[`row',2]=_b[T3]-_b[T2]

drop T1 T2 T3  temp r


display `row'
}
}

clear

svmat R

drop if R1==.
drop if R2==.


gen test1=(R1>.3435689 |R1<-.3435689)
gen test2=(R2>.2418858 |R2<-.2418858)

sum test*




************* Table 8A: private condition *********
set seed 1
set matsize 1000
capture log close
capture log using "Permutation_Table8A.log", replace

clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if public==0

******************  COLUMN 1 ******************
keep if public==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(190)


gen T = (temp<=94)

xi: reg taken_a T if public==0, r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.1332004 |R1<-.1332004)
sum test*

******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if public==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(190)


gen T = (temp<=94)

xi: reg taken_a T male age hispanic if public==0, r

mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.1304972  |R1<-.1304972 )
sum test*

******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if public==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(190)


gen T = (temp<=94)

xi: reg taken_a T  male age hispanic i.classroom i.surv if public==0, r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.
gen test1=(R1>.0989045 |R1<-.0989045)
sum test*


******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if public==0
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(190)


gen T = (temp<=94)

xi: reg junior T if public==0, r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}}

clear

svmat R

drop if R1==.

gen test1=(R1>.1476  |R1<-.1476 )
sum test*

******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if public==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(190)


gen T = (temp<=94)


xi: reg junior T male age hispanic if public==0, r

mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.1479  |R1<-.1479)
sum test*

******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
keep if public==0

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()
xtile temp=r , n(190)


gen T = (temp<=94)

xi: reg junior T  male age hispanic i.classroom i.surv if public==0, r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}

clear

svmat R

drop if R1==.
gen test1=(R1>.1188|R1<-.1188)
sum test*


**** Table 8B: Full sample ***
clear
set more off
clear matrix

set seed 1

set matsize 1000

capture log close

capture log using "Permutation_Table8B.log", replace

			
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
******************  COLUMN 1 ******************
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(395)


gen T = (temp<=190)

xi: reg taken_a T , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.0824134 |R1<-.0824134)
sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(395)


gen T = (temp<=190)

xi: reg taken_a T male age hispanic , r

mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.0786683   |R1<-.0786683)
sum test*

******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(395)


gen T = (temp<=190)

xi: reg taken_a T  male age hispanic i.classroom i.surv , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.
gen test1=(R1>.0806618  |R1<-.0806618 )
sum test*


******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(395)


gen T = (temp<=190)

xi: reg junior T , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.1154044  |R1<-.1154044 )
sum test*

******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(395)


gen T = (temp<=190)


xi: reg junior T male age hispanic , r

mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.1104373   |R1<-.1104373 )
sum test*

******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(395)


gen T = (temp<=190)

xi: reg junior T  male age hispanic i.classroom i.surv , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.
gen test1=(R1>.1007729|R1<-.1007729)
sum test*


**** TABLE 8C: Longer term outcomes
clear
set more off
clear matrix

set seed 1

set matsize 1000

capture log close

capture log using "Permutation_Table8C.log", replace

clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear

******************  COLUMN 1 ******************
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(340)


gen T = (temp<=168)

xi: reg taken_a T if takeup==1 , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.1557 |R1<-.1557)
sum test*



******************  COLUMN 2 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(340)


gen T = (temp<=168)

xi: reg taken_a T male age hispanic if takeup==1 , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.15|R1<-.15)
sum test*

******************  COLUMN 3 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(340)


gen T = (temp<=168)

xi: reg taken_a T male age hispanic i.classroom i.surv if takeup==1 , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'
}
}

clear

svmat R

drop if R1==.

gen test1=(R1>.1670 |R1<-.1670)
sum test*
******************  COLUMN 4 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(340)


gen T = (temp<=168)

xi: reg junior_y T if takeup==1 , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.1374 |R1<-.1374)
sum test*



******************  COLUMN 5 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 

mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(340)


gen T = (temp<=168)

xi: reg junior_y T male age hispanic if takeup==1 , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.13 |R1<-.13 )
sum test*

******************  COLUMN 6 ******************
clear matrix
set seed 1
set matsize 1000
use "bursztyn_egorov_jensen_restud.dta", clear
 
mat R=J(1000,1,.)

forvalues row=1(1)1000 {
quietly{
gen r=runiform()

xtile temp=r , n(340)


gen T = (temp<=168)

xi: reg junior_y T male age hispanic i.classroom i.surv if takeup==1 , r
mat R[`row',1]=_b[T]


drop T temp r

display `row'

}
}
clear

svmat R

drop if R1==.

gen test1=(R1>.1325  |R1<-.1325 )
sum test*

